import time
import os
import webbrowser
from .TresEnRaya import ter
from .PiedraPapelTijeras import ppt
from .Wordle import wrd

cls=lambda:os.system("cls" if os.name in ("nt","dos") else "clear")

def programaa():
    contador=1
    while contador==1:
        cls()
        print(f"Hola, ¿qué deseas hacer hoy? \n")
        print("-Buscar Definiciones (introduce buscar) ")
        print("-Jugar a juegos (introduce jugar) \n")
        pg=input("Hoy quiero ")
        while pg=="buscar":
            cls()
            x=input("Dime la palabra que deseas buscar: ")
            webbrowser.open(f"https://dle.rae.es/{x}")
            sal=input("¿Deseas buscar más palabras? ")
            if (sal=="No") or (sal=="no"):
                break
        if pg=="jugar":
            cls()
            print("Vale, tenemos estos juegos disponibles de momento: \n")
            print("Juego 1-Tres en raya (necesitas dos jugadores)(introduce 1) ")
            print("Juego 2-Piedra,papel o tijera (Juegas contra la IA)(introduce 2) ")
            print("Juego 3-Wordle (introduce 3) \n")
            ch=int(input("Elige el juego al que deses jugar: "))
            if ch==1:
                cls()
                ter()
            if ch==2:
                cls()
                ppt()
            if ch==3:
                cls()
                wrd()



import time
import random
import os
from colorama import Fore

cls = lambda: os.system("cls" if os.name in ("nt", "dos") else "clear")

def wrd():
  cls()
  palabra_del_dia = [
'abeto', 'altar', 'agudo', 'bache', 'bajar', 'beben', 'catar', 'camas',
'cosas', 'dedos', 'dejar', 'domar', 'error', 'ellos', 'enojo', 'fallo',
'feria', 'finca', 'gafas', 'galas', 'giras', 'halos', 'hasta', 'hielo',
'ideas', 'india', 'julio', 'jefas', 'lento', 'logro', 'lente', 'marco',
'morro', 'menos', 'negro', 'narco', 'orcos', 'preso', 'prosa', 'pinto',
'queso', 'rosas', 'retar', 'solos', 'salon', 'sabio', 'tonto', 'tomar',
'tabla', 'vagos', 'vacas', 'valor', 'yemas', 'yates', 'zurda', 'zorro'
  ]

  colors = {
'green': '\033[92m',
'yellow': '\033[93m',
'red': '\033[91m',
'ENDC': '\033[0m'
  }


  def color_letter(letter, color):
    return colors[color] + letter + colors['ENDC']


# init game
  print("Bienvenid@ al juego del Wordle!")
  time.sleep(1.5)
  eval = input('Sabes como funciona el juego: ')
  choice = eval.lower()
  time.sleep(1)
  win = False
  word = random.choice(palabra_del_dia)

  while choice == 'no':
    time.sleep(1)
    cls()
    print(
    "Basicamente, tienes que adivinar una palabra random en menos de 5 intentos\n"
    )
    time.sleep(2)
    print(
      Fore.GREEN +
      "Cuando las letras de la palabra que escribas coincidan con las de la palabra random, estas se pintarán de verde.\n"
    )
    time.sleep(2)
    print(
      Fore.YELLOW +
      "Si no están en la posición que debería pero si pertenecen a la palabra, estas se teñiran de amarillo\nTen cuidado, que la dificultad aumenta, porque si una letra sale amarilla y coincide con una verde, puede que esa letra amarilla se refiera a esa verde\n"
    )
    time.sleep(4)
    print(Fore.RED +
        "Y, por último, las letras rojas no pertenecen a la palabra random.\n")
    time.sleep(1.5)
    print(Fore.RESET + "Una vez adivinada, ganarás. ¿Ha quedado claro?")
    choice = input('Respuesta: ')
    choice = choice.lower()
    cls()
    if choice == 'si':
      print("Entonces, empecemos :D.\nEscriba una palabra para empezar: \n")
  else:
    print("\nEn ese caso, empecemos :D\n")
    time.sleep(1)
    print("Escribe una palabra para empezar: ")
  board = []
  for i in range(6):
    board.append(['_' for l in range(5)])  #lista in.r se guarda
  contador = 0
  while (not win) and (contador < len(word)):
    text = input("")
    while len(text) != len(word):
      print(Fore.RED + f"\n¡La palabra debe tener {len(word)} caracteres!\n")
      text = input("")
  # ganar
    if word == text:
      board[contador] = [l for l in text]
      cls()
      print("\nFelicidades has ganado!")
      win = True

  # letter in word
    else:
      test_line = []
      for j in range(len(text)):
        if text[j] == word[j]:  # la letra está
          test_line.append(color_letter(text[j], 'green'))
          cls()

        elif text[j] in word:  # la letra en otro sitio
          test_line.append(color_letter(text[j], 'yellow'))
          cls()
        else:  # la letra no está
          test_line.append(color_letter(text[j], 'red'))
          cls()
      board[contador] = test_line

  #draw
    for i in range(5):
      print(
      " ".join(board[i])
      )  #cada elemento de mi lista board lo transforme en un string que esté separado por un espacio

    contador += 1

  if win:
    print(Fore.GREEN+"\nFelicidades lo has conseguido!!")
    time.sleep(1)
    print(Fore.RESET)
  else:
    print(Fore.RED+f"\nVaya, la palabra era {word}. La próxima vez tendrás más suerte¡¡")
    time.sleep(1)
    print(Fore.RESET)





import time
import os
import colorama
from colorama import Fore

cls=lambda:os.system("cls" if os.name in ("nt","dos") else "clear")
def registro():
    cls()
    rg=Users.append(input("Dime tu nombre: "))
    rg1=Pss.append(input("Dime tu contraseña: "))
    time.sleep(0.5)
    print("Registro Completo :D ")
    time.sleep(0.5)
    cls()


import random
import time
from colorama import Fore
import os

cls= lambda:os.system("cls" if os.name in("nt","dos")else "clear")

def ppt():
    objeto = (['Piedra', 'Papel', 'Tijeras'])
    solucion = random.choice(objeto)
 
    print("Bienvenid@ al juego de piedra, papel o tijeras.")
    time.sleep(2)
    choice = input("¿Estás list@ para desafiar a la IA?: ")
 
    while choice == 'si' or choice == 's' or choice == 'Si':
        print("\nPerfecto.")
        time.sleep(1.5)
        cls()
        time.sleep(0.5)
        print("""Elija uno de los tres objetos (escribe la primera letra mayúscula):\n""")
        time.sleep(1)
        print("--> Piedra")
        time.sleep(0.5)
        print("--> Papel")
        time.sleep(0.5)
        print("--> Tijeras")
        time.sleep(2) #deja este así
        cls()
        obj = input("\nEscoja: ")
        while obj == solucion:
            time.sleep(1.5)
            print(f"\nTú oponente ha sacado {solucion} y tú has sacado {obj}")
            time.sleep(1)
            print(Fore.YELLOW + "\nVaya, ha habido un empate.")
            print(Fore.RESET + "")
            break


        while obj == 'Tijeras' and solucion == 'Piedra' or obj == 'Papel' and solucion == 'Tijeras' or obj == 'Piedra' and solucion == 'Papel':
            time.sleep(2)
            print(f"\nTú oponente ha sacado {solucion} y tú {obj}")
            time.sleep(1)
            print(Fore.RED + "\nVaya, me temo que has perdido.")
            print(Fore.RESET + "")
            time.sleep(1)
            break

        while obj == 'Piedra' and solucion == 'Tijeras' or obj == 'Tijeras' and solucion == 'Papel' or obj == 'Papel' and solucion == 'Piedra':
            time.sleep(2)
            print(f"\nTú oponente ha sacado {solucion} y tú {obj}")
            time.sleep(1)
            print(Fore.GREEN + "\nHas ganado!!")
            print(Fore.RESET + "")
            time.sleep(1)
            break
    
        choice = input("¿Desea continuar?: ")
        if choice == 'no' or choice == 'No':
            time.sleep(1)
            print(Fore.BLUE + "\nHasta pronto!!")
            print(Fore.RESET + "")
            break